@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """
 Verify that a module has a correct entry in the modules.json file
 """
@@ -7,8 +6,8 @@ import logging
 from pathlib import Path
 
 import nf_core
-import nf_core.modules.module_utils
 import nf_core.modules.modules_repo
+import nf_core.modules.modules_utils
 
 log = logging.getLogger(__name__)
 
@@ -23,11 +22,8 @@ def module_version(module_lint_object, module):
     """
 
     modules_json_path = Path(module_lint_object.dir, "modules.json")
-
     # Verify that a git_sha exists in the `modules.json` file for this module
-    version = module_lint_object.modules_json.get_module_version(
-        module.module_name, module_lint_object.modules_repo.remote_url, module_lint_object.modules_repo.repo_path
-    )
+    version = module_lint_object.modules_json.get_module_version(module.module_name, module.repo_url, module.org)
     if version is None:
         module.failed.append(("git_sha", "No git_sha entry in `modules.json`", modules_json_path))
         return
@@ -37,8 +33,12 @@ def module_version(module_lint_object, module):
 
     # Check whether a new version is available
     try:
-        modules_repo = nf_core.modules.modules_repo.ModulesRepo()
-        module_git_log = modules_repo.get_module_git_log(module.module_name)
+        module.branch = module_lint_object.modules_json.get_component_branch(
+            "modules", module.module_name, module.repo_url, module.org
+        )
+        modules_repo = nf_core.modules.modules_repo.ModulesRepo(remote_url=module.repo_url, branch=module.branch)
+
+        module_git_log = modules_repo.get_component_git_log(module.module_name, "modules")
         if version == next(module_git_log)["git_sha"]:
             module.passed.append(("module_version", "Module is the latest version", module.module_dir))
         else:
