@@ -7,17 +7,17 @@ from pathlib import Path
 import questionary
 
 import nf_core.utils
+from nf_core.components.components_command import ComponentCommand
 
-from .modules_command import ModuleCommand
 from .modules_differ import ModulesDiffer
 from .modules_json import ModulesJson
 
 log = logging.getLogger(__name__)
 
 
-class ModulePatch(ModuleCommand):
+class ModulePatch(ComponentCommand):
     def __init__(self, dir, remote_url=None, branch=None, no_pull=False):
-        super().__init__(dir, remote_url, branch, no_pull)
+        super().__init__("modules", dir, remote_url, branch, no_pull)
 
         self.modules_json = ModulesJson(dir)
 
@@ -25,7 +25,7 @@ class ModulePatch(ModuleCommand):
         if not self.has_valid_directory():
             raise UserWarning()
 
-        modules = self.modules_json.get_all_modules()[self.modules_repo.remote_url]
+        modules = self.modules_json.get_all_components(self.component_type)[self.modules_repo.remote_url]
         module_names = [module for _, module in modules]
 
         if module is not None and module not in module_names:
@@ -38,10 +38,13 @@ class ModulePatch(ModuleCommand):
 
         self.modules_json.check_up_to_date()
         self.param_check(module)
-        modules = self.modules_json.get_all_modules()[self.modules_repo.remote_url]
+        modules = self.modules_json.get_all_components(self.component_type)[self.modules_repo.remote_url]
 
         if module is None:
-            choices = [module if dir == "nf-core" else f"{dir}/{module}" for dir, module in modules]
+            choices = [
+                module if directory == self.modules_repo.repo_path else f"{directory}/{module}"
+                for directory, module in modules
+            ]
             module = questionary.autocomplete(
                 "Tool:",
                 choices,
@@ -50,7 +53,7 @@ class ModulePatch(ModuleCommand):
         module_dir = [dir for dir, m in modules if m == module][0]
         module_fullname = str(Path("modules", module_dir, module))
 
-        # Verify that the module has an entry is the modules.json file
+        # Verify that the module has an entry in the modules.json file
         if not self.modules_json.module_present(module, self.modules_repo.remote_url, module_dir):
             raise UserWarning(
                 f"The '{module_fullname}' module does not have an entry in the 'modules.json' file. Cannot compute patch"
@@ -62,7 +65,9 @@ class ModulePatch(ModuleCommand):
                 f"The '{module_fullname}' module does not have a valid version in the 'modules.json' file. Cannot compute patch"
             )
         # Get the module branch and reset it in the ModulesRepo object
-        module_branch = self.modules_json.get_module_branch(module, self.modules_repo.remote_url, module_dir)
+        module_branch = self.modules_json.get_component_branch(
+            self.component_type, module, self.modules_repo.remote_url, module_dir
+        )
         if module_branch != self.modules_repo.branch:
             self.modules_repo.setup_branch(module_branch)
 
@@ -86,7 +91,7 @@ class ModulePatch(ModuleCommand):
         # Create a temporary directory for storing the unchanged version of the module
         install_dir = tempfile.mkdtemp()
         module_install_dir = Path(install_dir, module)
-        if not self.install_module_files(module, module_version, self.modules_repo, install_dir):
+        if not self.install_component_files(module, module_version, self.modules_repo, install_dir):
             raise UserWarning(
                 f"Failed to install files of module '{module}' from remote ({self.modules_repo.remote_url})."
             )
