@@ -1,10 +1,10 @@
-#!/usr/bin/env python
 """Synchronise a pipeline TEMPLATE branch with the template.
 """
 
 import json
 import logging
 import os
+import re
 import shutil
 
 import git
@@ -33,7 +33,7 @@ class PullRequestException(Exception):
     pass
 
 
-class PipelineSync(object):
+class PipelineSync:
     """Object to hold syncing information and results.
 
     Args:
@@ -52,6 +52,7 @@ class PipelineSync(object):
         required_config_vars (list): List of nextflow variables required to make template pipeline
         gh_username (str): GitHub username
         gh_repo (str): GitHub repository name
+        template_yaml (str): Path to template.yml file for pipeline creation settings.
     """
 
     def __init__(
@@ -61,13 +62,15 @@ class PipelineSync(object):
         make_pr=False,
         gh_repo=None,
         gh_username=None,
+        template_yaml_path=None,
     ):
         """Initialise syncing object"""
 
         self.pipeline_dir = os.path.abspath(pipeline_dir)
         self.from_branch = from_branch
         self.original_branch = None
-        self.merge_branch = f"nf-core-template-merge-{nf_core.__version__}"
+        self.original_merge_branch = f"nf-core-template-merge-{nf_core.__version__}"
+        self.merge_branch = self.original_merge_branch
         self.made_changes = False
         self.make_pr = make_pr
         self.gh_pr_returned_data = {}
@@ -77,6 +80,12 @@ class PipelineSync(object):
         self.gh_repo = gh_repo
         self.pr_url = ""
 
+        self.template_yaml_path = template_yaml_path
+        # Save contents of template.yml for using outside of git.
+        if self.template_yaml_path is not None:
+            with open(self.template_yaml_path, "r") as template_yaml:
+                self.template_yaml_cache = template_yaml.read()
+
         # Set up the API auth if supplied on the command line
         self.gh_api = nf_core.utils.gh_api
         self.gh_api.lazy_init()
@@ -204,7 +213,7 @@ class PipelineSync(object):
         # Delete everything
         log.info("Deleting all files in 'TEMPLATE' branch")
         for the_file in os.listdir(self.pipeline_dir):
-            if the_file == ".git":
+            if the_file == ".git" or the_file == self.template_yaml_path:
                 continue
             file_path = os.path.join(self.pipeline_dir, the_file)
             log.debug(f"Deleting {file_path}")
@@ -225,16 +234,29 @@ class PipelineSync(object):
         # Only show error messages from pipeline creation
         logging.getLogger("nf_core.create").setLevel(logging.ERROR)
 
-        nf_core.create.PipelineCreate(
-            name=self.wf_config["manifest.name"].strip('"').strip("'"),
-            description=self.wf_config["manifest.description"].strip('"').strip("'"),
-            version=self.wf_config["manifest.version"].strip('"').strip("'"),
-            no_git=True,
-            force=True,
-            outdir=self.pipeline_dir,
-            author=self.wf_config["manifest.author"].strip('"').strip("'"),
-            plain=True,
-        ).init_pipeline()
+        # Re-write the template yaml from cache which may have been updated
+        if self.template_yaml_path and self.template_yaml_cache:
+            with open(self.template_yaml_path, "w") as template_path:
+                template_path.write(self.template_yaml_cache)
+
+        try:
+            nf_core.create.PipelineCreate(
+                name=self.wf_config["manifest.name"].strip('"').strip("'"),
+                description=self.wf_config["manifest.description"].strip('"').strip("'"),
+                version=self.wf_config["manifest.version"].strip('"').strip("'"),
+                no_git=True,
+                force=True,
+                outdir=self.pipeline_dir,
+                author=self.wf_config["manifest.author"].strip('"').strip("'"),
+                template_yaml_path=self.template_yaml_path,
+                plain=True,
+            ).init_pipeline()
+        except Exception as err:
+            # If sync fails, remove template_yaml_path before raising error.
+            os.remove(self.template_yaml_path)
+            # Reset to where you were to prevent git getting messed up.
+            self.repo.git.reset("--hard")
+            raise SyncException(f"Failed to rebuild pipeline from template with error:\n{err}")
 
     def commit_template_changes(self):
         """If we have any changes with the new template files, make a git commit"""
@@ -270,17 +292,18 @@ class PipelineSync(object):
         # Check if branch exists already
         branch_list = [b.name for b in self.repo.branches]
         if self.merge_branch in branch_list:
-            original_merge_branch = self.merge_branch
-            # Try to create new branch with number at the end
-            # If <branch_name>-2 already exists, increase the number until branch is new
-            branch_no = 2
-            self.merge_branch = f"{original_merge_branch}-{branch_no}"
-            while self.merge_branch in branch_list:
-                branch_no += 1
-                self.merge_branch = f"{original_merge_branch}-{branch_no}"
-            log.info(
-                f"Branch already existed: '{original_merge_branch}', creating branch '{self.merge_branch}' instead."
+            merge_branch_format = re.compile(rf"{self.original_merge_branch}-(\d+)")
+            max_branch = max(
+                [1]
+                + [
+                    int(merge_branch_format.match(branch).groups()[0])
+                    for branch in branch_list
+                    if merge_branch_format.match(branch)
+                ]
             )
+            new_branch = f"{self.original_merge_branch}-{max_branch+1}"
+            log.info(f"Branch already existed: '{self.merge_branch}', creating branch '{new_branch}' instead.")
+            self.merge_branch = new_branch
 
         # Create new branch and checkout
         log.info(f"Checking out merge base branch '{self.merge_branch}'")
@@ -423,4 +446,4 @@ class PipelineSync(object):
         try:
             self.repo.git.checkout(self.original_branch)
         except GitCommandError as e:
-            raise SyncException(f"Could not reset to original branch `{self.from_branch}`:\n{e}")
+            raise SyncException(f"Could not reset to original branch `{self.original_branch}`:\n{e}")
